"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = require("react");
var Utilities_1 = require("../../Utilities");
var Button_1 = require("../../Button");
var OverflowSet_1 = require("../../OverflowSet");
var ResizeGroup_1 = require("../../ResizeGroup");
var Tooltip_1 = require("../../Tooltip");
var Utilities_2 = require("../../Utilities");
var getClassNames = Utilities_2.classNamesFunction();
var CommandBarBase = /** @class */ (function (_super) {
    tslib_1.__extends(CommandBarBase, _super);
    function CommandBarBase() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CommandBarBase.prototype.render = function () {
        var _this = this;
        var _a = this.props, className = _a.className, endAligned = _a.endAligned, items = _a.items, overflowItems = _a.overflowItems, farItems = _a.farItems, elipsisAriaLabel = _a.elipsisAriaLabel, elipsisIconProps = _a.elipsisIconProps, buttonStyles = _a.buttonStyles, getStyles = _a.getStyles, theme = _a.theme, _b = _a.onRenderButton, onRenderButton = _b === void 0 ? this._onRenderButton : _b, _c = _a.onReduceData, onReduceData = _c === void 0 ? this._onReduceData : _c, _d = _a.onGrowData, onGrowData = _d === void 0 ? this._onGrowData : _d;
        var commandBardata = {
            primaryItems: items.slice(),
            overflowItems: overflowItems.slice(),
            minimumOverflowItems: overflowItems.slice().length,
            farItems: farItems,
            cacheKey: '',
        };
        this._classNames = getClassNames(getStyles, { theme: theme, className: className, endAligned: endAligned });
        return (React.createElement(ResizeGroup_1.ResizeGroup, { componentRef: this._resolveRef('_resizeGroup'), className: className, data: commandBardata, onReduceData: onReduceData, onGrowData: onGrowData, 
            // tslint:disable-next-line:jsx-no-lambda
            onRenderData: function (data) {
                return (React.createElement("div", { className: Utilities_1.css(_this._classNames.root) },
                    React.createElement(OverflowSet_1.OverflowSet, { componentRef: _this._resolveRef('_overflowSet'), className: Utilities_1.css(_this._classNames.primarySet), items: data.primaryItems, overflowItems: data.overflowItems.length ? data.overflowItems : undefined, onRenderItem: _this._onRenderItems, onRenderOverflowButton: function (renderedOverflowItems) {
                            return (onRenderButton({
                                key: 'oveflowButton',
                                styles: tslib_1.__assign({}, buttonStyles, { menuIcon: { fontSize: '17px' } }),
                                ariaLabel: elipsisAriaLabel,
                                className: Utilities_1.css('ms-CommandBar-overflowButton'),
                                menuProps: { items: renderedOverflowItems },
                                menuIconProps: elipsisIconProps,
                            }));
                        } }),
                    React.createElement(OverflowSet_1.OverflowSet, { className: Utilities_1.css(_this._classNames.secondarySet), items: data.farItems, onRenderItem: _this._onRenderItems, onRenderOverflowButton: function () { return null; } })));
            } }));
    };
    CommandBarBase.prototype.focus = function () {
        this._overflowSet.focus();
    };
    CommandBarBase.prototype.remeasure = function () {
        this._resizeGroup.remeasure();
    };
    CommandBarBase.prototype._computeCacheKey = function (primaryItems, farItems, overflow) {
        var returnKey = function (acc, current) {
            var _a = current.cacheKey, cacheKey = _a === void 0 ? current.key : _a;
            return acc + cacheKey;
        };
        var primaryKey = primaryItems.reduce(returnKey, '');
        var farKey = farItems.reduce(returnKey, '');
        var overflowKey = overflow ? 'overflow' : '';
        return [primaryKey, farKey, overflowKey].join(' ');
    };
    CommandBarBase.prototype._onReduceData = function (data) {
        var endAligned = this.props.endAligned;
        var farItems = data.farItems;
        var primaryItems = data.primaryItems, overflowItems = data.overflowItems, cacheKey = data.cacheKey;
        // Use first item if endAligned, otherwise use last item
        var movedItem = primaryItems[endAligned ? 0 : primaryItems.length - 1];
        if (movedItem !== undefined) {
            movedItem.renderedInOverflow = true;
            overflowItems = [movedItem].concat(overflowItems);
            primaryItems = endAligned ? primaryItems.slice(1) : primaryItems.slice(0, -1);
            cacheKey = this._computeCacheKey(primaryItems, farItems, !!overflowItems.length);
            return tslib_1.__assign({}, data, { primaryItems: primaryItems, overflowItems: overflowItems, cacheKey: cacheKey });
        }
        return undefined;
    };
    CommandBarBase.prototype._onGrowData = function (data) {
        var endAligned = this.props.endAligned;
        var minimumOverflowItems = data.minimumOverflowItems, farItems = data.farItems;
        var primaryItems = data.primaryItems, overflowItems = data.overflowItems, cacheKey = data.cacheKey;
        var movedItem = overflowItems[0];
        // Make sure that moved item exists and is not one of the original overflow items
        if (movedItem !== undefined && overflowItems.length > minimumOverflowItems) {
            movedItem.renderedInOverflow = false;
            overflowItems = overflowItems.slice(1);
            // if endAligned, movedItem goes first, otherwise, last.
            primaryItems = endAligned ? [movedItem].concat(primaryItems) : primaryItems.concat([movedItem]);
            cacheKey = this._computeCacheKey(primaryItems, farItems, !!overflowItems.length);
            return tslib_1.__assign({}, data, { primaryItems: primaryItems, overflowItems: overflowItems, cacheKey: cacheKey });
        }
        return undefined;
    };
    CommandBarBase.prototype._onRenderItems = function (item) {
        var buttonStyles = this.props.buttonStyles;
        if (item.onRender) {
            // These are the top level items, there is no relevant menu dismissing function to
            // provide for the IContextualMenuItem onRender function. Pass in a no op function instead.
            return item.onRender(item, function () { return undefined; });
        }
        var commandButtonProps = tslib_1.__assign({}, item, { styles: tslib_1.__assign({ root: { height: '100%' } }, item.buttonStyles, buttonStyles), className: Utilities_1.css(item.className), text: !item.iconOnly ? item.name : '', menuProps: item.subMenuProps });
        if (item.iconOnly && item.name !== undefined) {
            return (React.createElement(Tooltip_1.TooltipHost, { content: item.name }, this._onRenderButton(commandButtonProps)));
        }
        return this._onRenderButton(commandButtonProps);
    };
    CommandBarBase.prototype._onRenderButton = function (props) {
        // tslint:disable-next-line:no-any
        return React.createElement(Button_1.CommandBarButton, tslib_1.__assign({}, props));
    };
    CommandBarBase.defaultProps = {
        items: [],
        overflowItems: [],
        farItems: [],
        elipsisIconProps: { iconName: 'More' }
    };
    tslib_1.__decorate([
        Utilities_1.autobind
    ], CommandBarBase.prototype, "_onReduceData", null);
    tslib_1.__decorate([
        Utilities_1.autobind
    ], CommandBarBase.prototype, "_onGrowData", null);
    tslib_1.__decorate([
        Utilities_1.autobind
    ], CommandBarBase.prototype, "_onRenderItems", null);
    tslib_1.__decorate([
        Utilities_1.autobind
    ], CommandBarBase.prototype, "_onRenderButton", null);
    CommandBarBase = tslib_1.__decorate([
        Utilities_1.customizable('CommandBar', ['theme'])
    ], CommandBarBase);
    return CommandBarBase;
}(Utilities_1.BaseComponent));
exports.CommandBarBase = CommandBarBase;
//# sourceMappingURL=CommandBar.base.js.map